import unittest

from neo_skill import search


class SearchTests(unittest.TestCase):
    def test_search_returns_expected_result(self) -> None:
        self.assertEqual(search(), ["browser_use"])


if __name__ == "__main__":
    unittest.main()
